function y_mx_fit_from_excel
fsize = 18; %Fontsize for graphs

%Read Excel data
[filename, pathname] = uigetfile({'*.xls';'*xlsx'});
if isempty(pathname); return; end
[num,txt,raw] = xlsread( [pathname,filename] );
x = num(:,1).'; y = num(:,2).';

%Determine line of bets fit of the form y = mx
[yfit,xfit,r,m,dm,yupper,ylower,s] = bestfit(x,y);

%Plot line of best fit, overlaid with data
figure('name','line of best fit','color',[1 1 1]);
plot( xfit, yfit, 'k-', xfit, yupper, 'b--', xfit, ylower, 'g--' );
hold on; plot( x,y,'r+');
xlabel('x','fontsize',fsize); ylabel('y','fontsize',fsize);
set(gca,'fontsize',fsize); grid on;
title( {['Line of best fit y = ( ',num2str(m),' +/- ',num2str(dm,3),...
    ' )x, r = ',num2str(r,3)] }, 'fontsize',fsize );
print( gcf, [filename,'.png'],'-dpng','-r300' );
close(gcf);

%%

%Line of best fit function yfit = m*x, with product moment correlation
%coefficient r
function [yfit,xfit,r,m,dm,yupper,ylower,s] = bestfit(x,y)

%Find any x or y values that are NaN or Inf
ignore = isnan(abs(x)) | isnan(abs(y)) | isinf(abs(x)) | isinf(abs(y));
x(ignore) = []; y(ignore) = [];

%Compute line of best fit
xbar = mean(x); ybar = mean(y); xybar = mean(x.*y);
xxbar = mean(x.^2 ); yybar = mean(y.^2 );
Vx = xxbar - xbar^2; Vy = yybar - ybar^2;
COVxy = xybar - xbar*ybar;
m = xybar/xxbar; r = COVxy/sqrt( Vx*Vy );
[x,i] = sort(x); y = y(i);
yfit = m*x; xfit = x;

%Compute error in gradient m
n = length(x);
s = sqrt( (1/(n-1))*sum( (y - yfit).^2 ) );
dm = s/sqrt(n*Vx);

%Determine envelope lines
yupper = (m+dm)*x;
ylower = (m-dm)*x;

%End of code